# Fastidius


Fastidius is a CLI tool for creating [FastAPI](https://fastapi.tiangolo.com) backends, with integrations for deploying to DigitalOcean via Github.


## Installation

```
pip install fastidius
```

## Usage

To initialize a new project, run

```
fastidius create
```

This will take you through a few setup instructions.
If you have any issues, you might need to set
your python path:
```
export PYTHONPATH=.
```
